@@ -43,6 +43,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtQuickControls2TypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtQuickControls2Types;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtQuickControls2ModuleObject;
 
@@ -53,24 +56,20 @@ extern SbkConverter **SbkPySide6_QtQuickControls2TypeConverters;
 enum [[deprecated]] : int {
     SBK_QTQUICKCONTROLS2_QLIST_INT_IDX                       = 0, // QList<int>
     SBK_QTQUICKCONTROLS2_QLIST_QQUICKATTACHEDPROPERTYPROPAGATORPTR_IDX = 2, // QList<QQuickAttachedPropertyPropagator*>
-    SBK_QTQUICKCONTROLS2_QLIST_QOBJECTPTR_IDX                = 4, // QList<QObject*>
-    SBK_QTQUICKCONTROLS2_QLIST_QBYTEARRAY_IDX                = 6, // QList<QByteArray>
-    SBK_QTQUICKCONTROLS2_QLIST_QVARIANT_IDX                  = 8, // QList<QVariant>
-    SBK_QTQUICKCONTROLS2_QLIST_QSTRING_IDX                   = 10, // QList<QString>
-    SBK_QTQUICKCONTROLS2_QMAP_QSTRING_QVARIANT_IDX           = 12, // QMap<QString,QVariant>
-    SBK_QTQUICKCONTROLS2_CONVERTERS_IDX_COUNT                = 14,
+    SBK_QTQUICKCONTROLS2_QLIST_QVARIANT_IDX                  = 4, // QList<QVariant>
+    SBK_QTQUICKCONTROLS2_QLIST_QSTRING_IDX                   = 6, // QList<QString>
+    SBK_QTQUICKCONTROLS2_QMAP_QSTRING_QVARIANT_IDX           = 8, // QMap<QString,QVariant>
+    SBK_QTQUICKCONTROLS2_CONVERTERS_IDX_COUNT                = 10,
 };
 
 // Converter indices
 enum : int {
     SBK_QtQuickControls2_QList_int_IDX                       = 0, // QList<int>
     SBK_QtQuickControls2_QList_QQuickAttachedPropertyPropagatorPTR_IDX = 1, // QList<QQuickAttachedPropertyPropagator*>
-    SBK_QtQuickControls2_QList_QObjectPTR_IDX                = 2, // QList<QObject*>
-    SBK_QtQuickControls2_QList_QByteArray_IDX                = 3, // QList<QByteArray>
-    SBK_QtQuickControls2_QList_QVariant_IDX                  = 4, // QList<QVariant>
-    SBK_QtQuickControls2_QList_QString_IDX                   = 5, // QList<QString>
-    SBK_QtQuickControls2_QMap_QString_QVariant_IDX           = 6, // QMap<QString,QVariant>
-    SBK_QtQuickControls2_CONVERTERS_IDX_COUNT                = 7,
+    SBK_QtQuickControls2_QList_QVariant_IDX                  = 2, // QList<QVariant>
+    SBK_QtQuickControls2_QList_QString_IDX                   = 3, // QList<QString>
+    SBK_QtQuickControls2_QMap_QString_QVariant_IDX           = 4, // QMap<QString,QVariant>
+    SBK_QtQuickControls2_CONVERTERS_IDX_COUNT                = 5,
 };
 // Macros for type check
 
